---
title: '우리 회사는 개인정보 처리방침을 어떻게 준비해야 하나요? '
category: 자주 묻는 질문 (일반 문의) > 파트너정산자동화 > 파트너정산자동화
seo:
  title: '파트너정산 고객사 개인정보 처리방침 작성 가이드 '
  description: "\b파트너정산 자동화 서비스 이용 시, 고객사가 준비해야 하는 개인정보 처리방침 작성 가이드를 소개합니다.\n"
tags:
  - 정보보안
  - 개인정보처리방침
pgCompanies:
  - 공통
searchTags:
  - 개인정보위수탁
  - 정보보안
  - 개인정보처리방침
  - 파트너정산자동화
datetime: 2024-01-25T15:00:00.000Z
---

<Callout content="파트너정산 자동화 서비스 이용 시,  고객사가 준비해야 하는 개인정보 처리방침 작성 가이드를 소개합니다. " title="" />

### 개인정보 처리방침이란?

- 어떤 정보를 수집하고, 수집한 정보를 어떻게 사용하며, 필요에 따라 누구와 이를 공유 ("위탁 또는 제공")하는지 투명하게 제공하는 안내 사항입니다.
- 개인정보 침해 사고가 발생하는 경우, 추가적인 피해를 예방하고 이미 발생한 피해를 복구하기 위해서 누구에게 연락하여 어떤 도움을 받을 수 있는지 알리는 의미가 있습니다.
- 그 무엇보다도, 개인정보와 관련하여 고객사와 이용자간의 권리와 의무 관계를 규정하여 이용자의 '개인정보 자기 결정권'을 보장하는 수단이 됩니다.

### 왜 우리 회사가 준비해야 하나요?

- 파트너 정산 자동화 서비스의 \[송금대행 일괄지급], \[세금계산서 역발행] 등의 기능을 제공하기 위해 주식회사 코리아 포트원은 등록된 파트너의 개인정보를 제휴사에 (재)위탁하고 있습니다.
- 따라서 고객사는 서비스를 이용하기 위해 정산 대상자 \[파트너] 에게 개인정보 처리방침을 안내할 의무가 있습니다. 개인정보 위탁 및 재위탁에 대한 내용을 작성하여 파트너에게 안내해 주세요.
- (주)코리아포트원의 개인정보 처리방침은 [이 링크](https://portone.notion.site/f756e6b1a20d42e1af4dc887c9f8f420 "코리아포트원 개인정보처리방침")를 참고해 주세요.

### 개인정보처리방침 작성 가이드

<Callout content="개인정보 처리방침, 어렵지 않아요. 아래 내용을 참고하여 작성해주세요. " />

#### 작성 예시

회사(파트너사)는 원활한 개인정보 업무처리를 위하여 다음과 같이 개인정보 처리업무를 (재)위탁하고 있습니다. 개인정보보호법 제26조에 따라 수탁자가 당사의 개인정보 처리업무를 재위탁하는 경우 회사(파트너사)의 동의를 받고 있습니다.

| 위탁받는자 (수탁자) | 재위탁받는자 (재수탁자) | 위탁 업무                    |
| ----------- | ------------- | ------------------------ |
| (주)코리아포트원   | (주)링크허브       | 세금계산서 발행, 휴폐업 조회, 예금주 조회 |
| (주)코리아포트원   | (주)하이픈코퍼레이션   | 송금대행 서비스, 예금주 조회         |

위탁업무의 내용이나 수탁자 또는 재수탁자가 변경될 경우에는 지체없이 본 개인정보처리방침을 통하여 공개하도록 하겠습니다.

### 추가 질문이 있으시다면?

아래 연락처로 언제든지 편히 문의해주세요.

<Callout content="기술 문의 지원 이메일
b2b.support@portone.io" />

###
